package at.bestsolution.cef.util;

import java.util.concurrent.CompletableFuture;

public interface CefMessageLoopManager {
	
	/**
     * Start CEF and execution of the message loop.
     * 
     * Initializes CEF and then runs the message loop (see <code>CefRunMessageLoop</code>),
     * details of the message loop execution are implementation specific.
     * 
     * @return a {@link CompletableFuture} which completes when CEF has been initialized and 
     * is ready for usage (e.g. creation of browsers).
     */
    public CompletableFuture<Void> startMessageLoop();
    
    /**
     * Stop execution of the message loop and shutdown CEF.
     * 
     * @throws InterruptedException if the current thread is interrupted whilst
     * trying to stop execution
     */
    public void stopMessageLoop() throws InterruptedException;
}
